/*
Applet Jaxe - Editeur XML en Java

Copyright (C) 2007 Observatoire de Paris-Meudon

Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier conformment aux dispositions de la Licence Publique Gnrale GNU, telle que publie par la Free Software Foundation ; version 2 de la licence, ou encore ( votre choix) toute version ultrieure.

Ce programme est distribu dans l'espoir qu'il sera utile, mais SANS AUCUNE GARANTIE ; sans mme la garantie implicite de COMMERCIALISATION ou D'ADAPTATION A UN OBJET PARTICULIER. Pour plus de dtail, voir la Licence Publique Gnrale GNU .

Vous devez avoir reu un exemplaire de la Licence Publique Gnrale GNU en mme temps que ce programme ; si ce n'est pas le cas, crivez  la Free Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, Etats-Unis.
*/

package jaxeapplet;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.io.StringReader;
import java.io.StringWriter;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URL;

import javax.swing.*;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.xml.sax.InputSource;
import org.w3c.dom.Document;


/**
 * Applet permettant d'diter un fichier XML avec Jaxe.
 *
 * Paramtres :
 * - config : chemin vers la config Jaxe par rapport au document HTML
 * - fichier : URL du fichier XML
 * - nouveau : "oui" ou "non", pour savoir si c'est un nouveau fichier
 * - dictionnaire : chemin vers le fichier .dico par rapport au document HTML (optionnel)
 * - phonetique : chemin vers le fichier .phon par rapport au document HTML (optionnel)
 * - enregistrement : URL relative  l'adresse de la page web, o sera envoye le contenu avec une requte POST (obligatoire si fichier est dfini)
 *
 * Il y a 2 faons d'utiliser cette applet :
 * - avec les paramtres fichier et enregistrement, sans Javascript.
 * Dans ce cas, le fichier sera lu depuis l'URL fichier, et enregistr avec le script donn par le paramtre enregistrement
 * (requte POST, paramtres chemin et contenu).
 * - avec du Javascript en utilisant la mthode editer() pour dfinir le XML, getEditing() rgulirement pour attendre la fin de l'dition,
 * puis getTexte() pour rcurper le XML dit.
 */
public class JaxeApplet extends JApplet {
    
    protected String scriptEnregistrement;
    protected String cheminConfig;
    protected JaxeAppletFrame frame;
    protected boolean editing;
    protected String fichierAEditer;
    protected boolean nouveau;
    protected String cheminDictionnaire;
    protected String cheminPhonetique;
    
    public void init() {
        cheminConfig = getParameter("config");
        fichierAEditer = getParameter("fichier");
        String sNouveau = getParameter("nouveau");
        cheminDictionnaire = getParameter("dictionnaire");
        cheminPhonetique = getParameter("phonetique");
        scriptEnregistrement = getParameter("enregistrement");
        nouveau = sNouveau != null && !"".equals(sNouveau) && "oui".equals(sNouveau);
        editing = false;
        
        // bug couleurs Safari sur Leopard
        if (System.getProperty("os.name").startsWith("Mac OS") &&
                System.getProperty("os.version").startsWith("10.5")) {
            UIManager.put("Panel.background", new Color(232,232,232));
            UIManager.put("Label.background", new Color(232,232,232));
            UIManager.put("SplitPane.background", new Color(232,232,232));
        }
    }
    
    public void start() {
        if (fichierAEditer != null)
            editerFichier(fichierAEditer);
    }
    
    /**
     * Lance l'dition du XML donn en paramtre.
     */
    public void editer(String texte) {
        editing = true;
        SwingUtilities.invokeLater(new Edition(texte)); // pour viter un bug de Safari/Mac (ContextClassLoader null)
    }
    
    class Edition implements Runnable {
        private String texte;
        public Edition(final String texte) {
            this.texte = texte;
        }
        public void run() {
            editer2(texte);
        }
    }
    
    protected void editer2(String texte) {
        Document ddoc = null;
        if (texte != null && !"".equals(texte)) {
            try {
                final DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
                dbf.setNamespaceAware(true);
                final DocumentBuilder docbuilder = dbf.newDocumentBuilder();
                InputSource is = new InputSource(new StringReader(texte));
                ddoc = docbuilder.parse(is);
            } catch (final Exception ex) {
                String msg = "JaxeApplet : " + ex.getClass().getName() + " : " + ex.getMessage();
                JOptionPane.showMessageDialog(null, msg, "Lecture document", JOptionPane.ERROR_MESSAGE);
                return;
            }
        }
        try {
            URL urlCfg = new URL(getDocumentBase(), cheminConfig);
            frame = new JaxeAppletFrame(urlCfg, ddoc);
            frame.setActionFermeture(new AbstractAction() {
                public void actionPerformed(ActionEvent e) {
                    fermetureEdition();
                }
            });
            frame.setVisible(true);
        } catch (MalformedURLException ex) {
            String msg = ex.getClass().getName() + " : " + ex.getMessage();
            JOptionPane.showMessageDialog(null, msg, "Lecture config", JOptionPane.ERROR_MESSAGE);
        }
    }
    
    /**
     * Lance l'dition du fichier XML dont l'URL est donne en paramtre sous forme de String.
     */
    public void editerFichier(String nomFichier) {
        editing = true;
        URL urlFichier, urlCfg, urlEnregistrement, urlDictionnaire=null, urlPhonetique=null;
        try {
            urlFichier = new URL(new URI(nomFichier).toASCIIString());
        } catch (Exception ex) {
            String msg = ex.getClass().getName() + " : " + ex.getMessage();
            msg += "\n (nomFichier:" + nomFichier + ")";
            JOptionPane.showMessageDialog(null, msg, "URL du fichier", JOptionPane.ERROR_MESSAGE);
            return;
        }
        try {
            urlCfg = new URL(getDocumentBase(), cheminConfig);
        } catch (MalformedURLException ex) {
            String msg = ex.getClass().getName() + " : " + ex.getMessage();
            msg += "\n (cheminConfig:" + cheminConfig + ")";
            JOptionPane.showMessageDialog(null, msg, "URL config de Jaxe", JOptionPane.ERROR_MESSAGE);
            return;
        }
        try {
            urlEnregistrement = new URL(getDocumentBase(), scriptEnregistrement);
        } catch (MalformedURLException ex) {
            String msg = ex.getClass().getName() + " : " + ex.getMessage();
            msg += "\n (scriptEnregistrement:" + scriptEnregistrement + ")";
            JOptionPane.showMessageDialog(null, msg, "URL du script d'enregistrement", JOptionPane.ERROR_MESSAGE);
            return;
        }
        if (cheminDictionnaire != null && !"".equals(cheminDictionnaire)) {
            try {
                urlDictionnaire = new URL(getDocumentBase(), cheminDictionnaire);
                if (cheminPhonetique != null && !"".equals(cheminPhonetique)) {
                    try {
                        urlPhonetique = new URL(getDocumentBase(), cheminPhonetique);
                    } catch (MalformedURLException ex) {
                        String msg = ex.getClass().getName() + " : " + ex.getMessage();
                        msg += "\n (cheminPhonetique:" + cheminPhonetique + ")";
                        JOptionPane.showMessageDialog(null, msg, "URL phonetique", JOptionPane.ERROR_MESSAGE);
                        return;
                    }
                }
            } catch (MalformedURLException ex) {
                String msg = ex.getClass().getName() + " : " + ex.getMessage();
                msg += "\n (cheminDictionnaire:" + cheminDictionnaire + ")";
                JOptionPane.showMessageDialog(null, msg, "URL dictionnaire", JOptionPane.ERROR_MESSAGE);
                return;
            }
        }
        frame = new JaxeAppletFrame(urlCfg, urlFichier, urlEnregistrement, urlDictionnaire, urlPhonetique, nouveau);
        frame.setActionFermeture(new AbstractAction() {
            public void actionPerformed(ActionEvent e) {
                fermetureEdition();
            }
        });
        frame.setVisible(true);
    }
    
    /**
     * Mthode appele  la fermeture de la fentre d'dition.
     */
    public void fermetureEdition() {
        editing = false;
    }
    
    /**
     * Renvoit le texte complet du XML modifi par l'dition.
     */
    public String getTexte() {
        if (frame == null) {
            System.err.println("JaxeApplet.getTexte : frame est null");
            return(null);
        }
        StringWriter sw = new StringWriter();
        frame.sendToWriter(sw);
        return(sw.toString());
    }
    
    /**
     * Renvoit true si une dition est en cours (avec une fentre ouverte).
     */
    public boolean getEditing() {
        return(editing);
    }
    
}
