<?php
// WebJaxe, Observatoire de Paris, licence GPL
// encodage : UTF-8

// lecture d'un fichier du répertoire contribXML ou du répertoire sites avec vérification du droit d'accès
// utilisation: lecture_fichier.php?fichier=chemin/vers/le/fichier (sur le serveur)

session_start();

if (!isset($_SESSION['langue']) || !$_SESSION['langue'])
    $_SESSION['langue'] = "fr";
$fichierlangue = "../../langues/".$_SESSION['langue'].".php";
require_once($fichierlangue);
require_once("../include/utilisateurs.php");
require_once("../include/outils.php");
require_once("../include/base_de_donnees.php");

init_erreurs_texte();

$_SESSION['section'] = 'utilisateur';

if (!isset($_SESSION['id_utilisateur'])) {
// l'erreur peut être causée sur Firefox qui ne transmet pas les cookies de session à l'applet
//   quand "Accepter les cookies tiers" est désactivé (bugzilla #441166)
    header('HTTP/1.0 403 Forbidden');
    header("content-type:text/plain; charset=utf-8");
    echo PAS_DE_SESSION;
    exit;
}

if (!isset($_GET['fichier']))
    erreur(PARAMETRES_MANQUANT);

$id_utilisateur = $_SESSION['id_utilisateur'];
$chemin = utf8_decode($_GET['fichier']);

// vérif que le chemin commence bien par le chemin vers le dossier de WebJaxe
$urlb = $_SERVER['PHP_SELF'];
$path_parts = pathinfo($urlb);
$dossier_racine = $path_parts['dirname'];
$tdr = explode('/', $dossier_racine);
array_splice($tdr, count($tdr) - 2);
$dossier_webjaxe = implode('/', $tdr);
$pos = strpos($chemin, $dossier_webjaxe);
if ($pos === false || $pos != 0) {
    header('HTTP/1.0 403 Forbidden');
    header("content-type:text/plain; charset=utf-8");
    echo PAS_AUTORISE.' - '.$chemin;
    exit;
}

// vérif que le fichier demandé est bien dans le répertoire contribXML ou le répertoire sites
$chemin_relatif = substr($chemin, strlen($dossier_webjaxe));
$real_chemin = realpath('../..'.$chemin_relatif);
if ($real_chemin == false) {
    header('HTTP/1.0 404 Not Found');
    header("content-type:text/plain; charset=utf-8");
    echo '404 Not Found';
    exit;
}
$real_contribXML = realpath("../../contribXML");
$real_sites = realpath("../../sites");
$pos = strpos($real_chemin, $real_contribXML);
$dans_contribXML = !($pos === false || $pos != 0);
$pos = strpos($real_chemin, $real_sites);
$dans_sites = !($pos === false || $pos != 0);
if (!$dans_contribXML && !$dans_sites) {
    header('HTTP/1.0 403 Forbidden');
    header("content-type:text/plain; charset=utf-8");
    echo PAS_AUTORISE.' - '.$chemin;
    exit;
}

// obtention du nom de la contribution
if ($dans_contribXML)
    $real_avant_nom_contrib = $real_contribXML.'/';
else
    $real_avant_nom_contrib = $real_sites.'/';
$contrib = substr($real_chemin, strlen($real_avant_nom_contrib));
$pos = strpos($contrib, '/');
if ($pos === false) {
    header('HTTP/1.0 403 Forbidden');
    header("content-type:text/plain; charset=utf-8");
    echo PAS_AUTORISE.' - '.$chemin;
    exit;
}
$contrib = substr($contrib, 0, $pos);

// vérif que l'utilisateur a le droit de lecture de la contribution
verifier_l_utilisateur($id_utilisateur, false, $contrib);

// envoi du contenu du fichier
if (!file_exists($real_chemin)) {
    header('HTTP/1.0 404 Not Found');
    header("content-type:text/plain; charset=utf-8");
    echo '404 Not Found';
    exit;
} else {
    header('Content-Type: '.getMimeType($real_chemin));
    header('Content-Length: '.filesize($real_chemin));
    header('Last-Modified: '.date('r', filemtime($real_chemin)));
    readfile($real_chemin);
}


function getMimeType($file_path) {
    $mtype = '';
    $mime_types = array(
        'txt' => 'text/plain',
        'htm' => 'text/html',
        'html' => 'text/html',
        'xhtml' => 'application/xhtml+xml',
        'css' => 'text/css',
        'js' => 'application/javascript',
        'xml' => 'application/xml',
        'swf' => 'application/x-shockwave-flash',
        'png' => 'image/png',
        'jpeg' => 'image/jpeg',
        'jpg' => 'image/jpeg',
        'gif' => 'image/gif',
        'mpg' => 'video/mpeg',
        'mpeg' => 'video/mpeg',
        'ogv' => 'video/ogg',
        'class' => 'application/java',
        'jar' => 'application/java-archive'
    );

    $ext = strtolower(substr($file_path, strrpos($file_path, '.') + 1));
    if (array_key_exists($ext, $mime_types)) {
        $mtype = $mime_types[$ext];
    } else if (function_exists('mime_content_type')) {
         $mtype = mime_content_type($file_path);
    } else if (function_exists('finfo_file')) {
        $finfo = finfo_open(FILEINFO_MIME);
        $mtype = finfo_file($finfo, $file_path);
        finfo_close($finfo);  
    }
    if ($mtype == '') {
        $mtype = 'application/octet-stream';
    }
    return $mtype;
}

?>
